# Generated by ariadne-codegen
# Source: operations.graphql

from stigg._vendors.pydantic import Field

from .base_model import BaseModel


class ReportEntitlementCheckRequested(BaseModel):
    report_entitlement_check_requested: bool = Field(
        alias="reportEntitlementCheckRequested"
    )
